==> v8.3.zip: ru_twords_ru_tw/bible/other/feast.md <==
# пир, пировать

## Определение:

Пир — это богатое застолье с обилием пищи и напитков. Пировать — значит вместе с другими есть богатое угощение и пить алкогольные напитки, например, вино. Чаще всего пиры устраивались в честь какого-либо знаменательного события, а иногда и без него.

* Часто на пирах подавались особо изысканные блюда.
* Религиозные праздники, отмечавшиеся иудеями, часто сопровождались богатым застольем. Поэтому зачастую их называли пирами.
* В древние времена цари и вельможи часто устраивали пиры, чтобы повеселиться вместе со знатью.
* В истории о блудном сыне рассказывается, что отец устроил пир в честь возвращения своего сына.
* Пиры могли длиться в течение нескольких дней и даже недель.
* Слово “пировать” можно перевести как “участвовать в застолье”, “проводить время за богатым угощением”.
* В зависимости от контекста слово “пир” можно перевести как “праздник с богатым угощением”, “богатое застолье”, “праздничное угощение”.

(См. также: [праздник](../other/festival.md))

## Ссылки на библейский текст:

* [2 Пет. 2:12-14](rc://*/tn/help/2pe/02/12)
* [Быт. 26:30-31](rc://*/tn/help/gen/26/30)
* [Быт. 29:21-22](rc://*/tn/help/gen/29/21)
* [Быт. 40:20-23](rc://*/tn/help/gen/40/20)
* [Jude 1:12-13](rc://*/tn/help/jud/01/12)
* [Лк. 2:41-44](rc://*/tn/help/luk/02/41)
* [Лк. 14:7-9](rc://*/tn/help/luk/14/07)
* [Мф. 22:1-3](rc://*/tn/help/mat/22/01)

## Данные о слове:

* Номера Стронга: H398, H2077, H2282, H2287, H3899, H3900, H4150, H4580, H4797, H4960, H7646, H8057, H8354, G26, G755, G1062, G1173, G1403, G1456, G1858, G1859, G2165, G3521, G4910

==> v9.2.zip: ru_twords_ru_tw/bible/other/feast.md <==
# пир, пировать

## Определение:

Пир — это богатое застолье с обилием пищи и напитков. Пировать — значит вместе с другими есть богатое угощение и пить алкогольные напитки, например, вино. Чаще всего пиры устраивались в честь какого-либо знаменательного события, а иногда и без него.

* Часто на пирах подавались особо изысканные блюда. 
* Религиозные праздники, отмечавшиеся иудеями, часто сопровождались богатым застольем. Поэтому зачастую их называли пирами. 
* В древние времена цари и вельможи часто устраивали пиры, чтобы повеселиться вместе со знатью. 
* В истории о блудном сыне рассказывается, что отец устроил пир в честь возвращения своего сына. 
* Пиры могли длиться в течение нескольких дней и даже недель. 
* Слово “пировать” можно перевести как “участвовать в застолье”, “проводить время за богатым угощением”. 
* В зависимости от контекста слово “пир” можно перевести как “праздник с богатым угощением”, “богатое застолье”, “праздничное угощение”. 

(См. также: [праздник](../other/festival.md))

## Ссылки на библейский текст:

* [2 Пет. 2:12-14](rc://ru/tn/help/2pe/02/12)
* [Быт. 26:30-31](rc://ru/tn/help/gen/26/30)
* [Быт. 29:21-22](rc://ru/tn/help/gen/29/21)
* [Быт. 40:20-23](rc://ru/tn/help/gen/40/20)
* [Jude 1:12-13](rc://ru/tn/help/jud/01/12)
* [Лк. 2:41-44](rc://ru/tn/help/luk/02/41)
* [Лк. 14:7-9](rc://ru/tn/help/luk/14/07)
* [Мф. 22:1-3](rc://ru/tn/help/mat/22/01)

## Данные о слове:

* Номера Стронга: H398, H2077, H2282, H2287, H3899, H3900, H4150, H4580, H4797, H4960, H7646, H8057, H8354, G26, G755, G1062, G1173, G1403, G1456, G1858, G1859, G2165, G3521, G4910
